@@ -1,11 +1,10 @@
-// Copyright 2020 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
-// This SAFE Network Software is licensed to you under the MIT license <LICENSE-MIT
-// http://opensource.org/licenses/MIT> or the Modified BSD license <LICENSE-BSD
-// https://opensource.org/licenses/BSD-3-Clause>, at your option. This file may not be copied,
-// modified, or distributed except according to those terms. Please review the Licences for the
-// specific language governing permissions and limitations relating to use of the SAFE Network
-// Software.
+// This SAFE Network Software is licensed to you under The General Public License (GPL), version 3.
+// Unless required by applicable law or agreed to in writing, the SAFE Network Software distributed
+// under the GPL Licence is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+// KIND, either express or implied. Please review the Licences for the specific language governing
+// permissions and limitations relating to use of the SAFE Network Software.
 
 use super::{
     helpers::{get_from_arg_or_stdin, print_nrs_map, serialise_output, xorname_to_hex},
@@ -61,7 +60,7 @@ pub async fn dog_commander(cmd: DogCommands, output_fmt: OutputFmt, safe: &mut S
                     println!("Native data type: {}", data_type);
                     let mut safeurl = SafeUrl::from_url(xorurl)?;
                     safeurl.set_content_type(ContentType::Raw)?;
-                    println!("Native data XOR-URL: {}", safeurl.to_string());
+                    println!("Native data XOR-URL: {}", safeurl);
                     print_nrs_map(nrs_map, public_name);
                 }
                 SafeData::FilesContainer {
@@ -85,9 +84,9 @@ pub async fn dog_commander(cmd: DogCommands, output_fmt: OutputFmt, safe: &mut S
                     println!("Native data type: {}", data_type);
                     let mut safeurl = SafeUrl::from_url(xorurl)?;
                     safeurl.set_content_type(ContentType::Raw)?;
-                    println!("Native data XOR-URL: {}", safeurl.to_string());
+                    println!("Native data XOR-URL: {}", safeurl);
                 }
-                SafeData::PublicBlob {
+                SafeData::PublicFile {
                     xorurl,
                     xorname,
                     media_type,
@@ -98,7 +97,7 @@ pub async fn dog_commander(cmd: DogCommands, output_fmt: OutputFmt, safe: &mut S
                     println!("= File =");
                     println!("XOR-URL: {}", xorurl);
                     println!("XOR name: 0x{}", xorname_to_hex(xorname));
-                    println!("Native data type: PublicBlob");
+                    println!("Native data type: PublicFile");
                     println!(
                         "Media type: {}",
                         media_type.clone().unwrap_or_else(|| "Unknown".to_string())
