@@ -1,11 +1,10 @@
-// Copyright 2020 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
-// This SAFE Network Software is licensed to you under the MIT license <LICENSE-MIT
-// http://opensource.org/licenses/MIT> or the Modified BSD license <LICENSE-BSD
-// https://opensource.org/licenses/BSD-3-Clause>, at your option. This file may not be copied,
-// modified, or distributed except according to those terms. Please review the Licences for the
-// specific language governing permissions and limitations relating to use of the SAFE Network
-// Software.
+// This SAFE Network Software is licensed to you under The General Public License (GPL), version 3.
+// Unless required by applicable law or agreed to in writing, the SAFE Network Software distributed
+// under the GPL Licence is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+// KIND, either express or implied. Please review the Licences for the specific language governing
+// permissions and limitations relating to use of the SAFE Network Software.
 
 use super::{
     files_get::{process_get_command, FileExistsAction, ProgressIndicator},
@@ -104,7 +103,7 @@ pub enum FilesSubCommands {
         /// The source file/folder local path
         location: String,
         /// The destination path (in the FilesContainer) for the uploaded files and folders (default is '/')
-        dest: Option<PathBuf>,
+        dst: Option<PathBuf>,
         /// Recursively upload folders and files found in the source location
         #[structopt(short = "r", long = "recursive")]
         recursive: bool,
@@ -117,7 +116,7 @@ pub enum FilesSubCommands {
         /// The target FilesContainer to retrieve from, optionally including the path to the directory or file within
         source: String,
         /// The local destination path for the retrieved files and folders (default is '.')
-        dest: Option<String>,
+        dst: Option<String>,
         /// How to handle pre-existing files.
         #[structopt(short = "e", long = "exists", possible_values = &["ask", "preserve", "overwrite"], default_value="ask")]
         exists: FileExistsAction,
@@ -208,7 +207,7 @@ pub async fn files_commander(
     match cmd {
         FilesSubCommands::Put {
             location,
-            dest,
+            dst,
             recursive,
             follow_links,
         } => {
@@ -217,7 +216,7 @@ pub async fn files_commander(
                 notice_dry_run();
             }
             let (files_container_xorurl, processed_files, _) = safe
-                .files_container_create_from(&location, dest.as_deref(), recursive, follow_links)
+                .files_container_create_from(&location, dst.as_deref(), recursive, follow_links)
                 .await?;
 
             // Now let's just print out a list of the files uploaded/processed
@@ -369,7 +368,7 @@ pub async fn files_commander(
                     let (total, filtered_filesmap) = filter_files_map(&files_map, &target_url)?;
                     (version, filtered_filesmap, total)
                 }
-                SafeData::PublicBlob { metadata, .. } => {
+                SafeData::PublicFile { metadata, .. } => {
                     if let Some(file_item) = metadata {
                         let mut files_map = FilesMap::new();
                         let name = match file_item.get("name") {
@@ -406,11 +405,11 @@ pub async fn files_commander(
         }
         FilesSubCommands::Get {
             source,
-            dest,
+            dst,
             exists,
             progress,
             preserve,
-        } => process_get_command(safe, source, dest, exists, progress, preserve, output_fmt).await,
+        } => process_get_command(safe, source, dst, exists, progress, preserve, output_fmt).await,
     }
 }
 
