@@ -1,11 +1,10 @@
-// Copyright 2020 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
-// This SAFE Network Software is licensed to you under the MIT license <LICENSE-MIT
-// http://opensource.org/licenses/MIT> or the Modified BSD license <LICENSE-BSD
-// https://opensource.org/licenses/BSD-3-Clause>, at your option. This file may not be copied,
-// modified, or distributed except according to those terms. Please review the Licences for the
-// specific language governing permissions and limitations relating to use of the SAFE Network
-// Software.
+// This SAFE Network Software is licensed to you under The General Public License (GPL), version 3.
+// Unless required by applicable law or agreed to in writing, the SAFE Network Software distributed
+// under the GPL Licence is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+// KIND, either express or implied. Please review the Licences for the specific language governing
+// permissions and limitations relating to use of the SAFE Network Software.
 
 use assert_cmd::prelude::*;
 use assert_fs::prelude::*;
@@ -57,7 +56,7 @@ fn nrs_register_should_register_a_topname_with_a_versioned_content_link() -> Res
     )))
     .stdout(predicate::str::contains(format!(
         "The entry points to {}",
-        url.to_string()
+        url
     )));
     Ok(())
 }
@@ -73,12 +72,12 @@ fn nrs_register_should_register_a_topname_with_an_immutable_content_link() -> Re
         .iter()
         .last()
         .ok_or_else(|| eyre!("list of processed files unexpectedly empty"))?;
-    let test_md_blob_link = test_md_entry
+    let test_md_file_link = test_md_entry
         .1
         .to_owned()
         .link()
         .ok_or_else(|| eyre!("Missing xorurl link of uploaded test file"))?;
-    let url = SafeUrl::from_url(test_md_blob_link)?;
+    let url = SafeUrl::from_url(test_md_file_link)?;
     println!("processed_files = {:?}", processed_files);
 
     let topname = get_random_nrs_string();
@@ -93,7 +92,7 @@ fn nrs_register_should_register_a_topname_with_an_immutable_content_link() -> Re
     )))
     .stdout(predicate::str::contains(format!(
         "The entry points to {}",
-        url.to_string()
+        url
     )));
     Ok(())
 }
@@ -219,12 +218,12 @@ fn nrs_add_should_add_a_subname_to_immutable_content() -> Result<()> {
         .iter()
         .last()
         .ok_or_else(|| eyre!("list of processed files unexpectedly empty"))?;
-    let test_md_blob_link = test_md_entry
+    let test_md_file_link = test_md_entry
         .1
         .to_owned()
         .link()
         .ok_or_else(|| eyre!("Missing xorurl link of uploaded test file"))?;
-    let url = SafeUrl::from_url(test_md_blob_link)?;
+    let url = SafeUrl::from_url(test_md_file_link)?;
 
     let test_name = get_random_nrs_string();
     let public_name = format!("test.{}", &test_name);
